@@ -491,7 +491,7 @@ Tcl_GetStringResult(
     Interp *iPtr = (Interp *) interp;
 
     if (*(iPtr->result) == 0) {
-	Tcl_SetResult(interp, TclGetString(Tcl_GetObjResult(interp)),
+	Tcl_SetResult(interp, Tcl_GetString(Tcl_GetObjResult(interp)),
 		TCL_VOLATILE);
     }
     return iPtr->result;
@@ -1334,7 +1334,7 @@ TclProcessReturn(
 	if (valuePtr != NULL) {
 	    Tcl_SetObjErrorCode(interp, valuePtr);
 	} else {
-	    Tcl_SetErrorCode(interp, "NONE", NULL);
+	    Tcl_SetErrorCode(interp, "NONE", (char *)NULL);
 	}
 
 	Tcl_DictObjGet(NULL, iPtr->returnOpts, keys[KEY_ERRORLINE],
@@ -1416,7 +1416,7 @@ TclMergeReturnOptions(
                         "bad %s value: expected dictionary but got \"%s\"",
                         compare, TclGetString(objv[1])));
 		Tcl_SetErrorCode(interp, "TCL", "RESULT", "ILLEGAL_OPTIONS",
-			NULL);
+			(char *)NULL);
 		goto error;
 	    }
 
@@ -1465,7 +1465,7 @@ TclMergeReturnOptions(
 	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
                     "bad -level value: expected non-negative integer but got"
                     " \"%s\"", TclGetString(valuePtr)));
-	    Tcl_SetErrorCode(interp, "TCL", "RESULT", "ILLEGAL_LEVEL", NULL);
+	    Tcl_SetErrorCode(interp, "TCL", "RESULT", "ILLEGAL_LEVEL", (char *)NULL);
 	    goto error;
 	}
 	Tcl_DictObjRemove(NULL, returnOpts, keys[KEY_LEVEL]);
@@ -1488,7 +1488,7 @@ TclMergeReturnOptions(
                     "bad -errorcode value: expected a list but got \"%s\"",
                     TclGetString(valuePtr)));
 	    Tcl_SetErrorCode(interp, "TCL", "RESULT", "ILLEGAL_ERRORCODE",
-		    NULL);
+		    (char *)NULL);
 	    goto error;
 	}
     }
@@ -1510,7 +1510,7 @@ TclMergeReturnOptions(
                     "bad -errorstack value: expected a list but got \"%s\"",
                     TclGetString(valuePtr)));
 	    Tcl_SetErrorCode(interp, "TCL", "RESULT", "NONLIST_ERRORSTACK",
-                    NULL);
+                    (char *)NULL);
 	    goto error;
 	}
         if (length % 2) {
@@ -1522,7 +1522,7 @@ TclMergeReturnOptions(
                     "forbidden odd-sized list for -errorstack: \"%s\"",
 		    TclGetString(valuePtr)));
 	    Tcl_SetErrorCode(interp, "TCL", "RESULT",
-                    "ODDSIZEDLIST_ERRORSTACK", NULL);
+                    "ODDSIZEDLIST_ERRORSTACK", (char *)NULL);
 	    goto error;
         }
     }
@@ -1675,7 +1675,7 @@ Tcl_SetReturnOptions(
 	    || (objc % 2)) {
 	Tcl_SetObjResult(interp, Tcl_ObjPrintf(
                 "expected dict but got \"%s\"", TclGetString(options)));
-	Tcl_SetErrorCode(interp, "TCL", "RESULT", "ILLEGAL_OPTIONS", NULL);
+	Tcl_SetErrorCode(interp, "TCL", "RESULT", "ILLEGAL_OPTIONS", (char *)NULL);
 	code = TCL_ERROR;
     } else if (TCL_ERROR == TclMergeReturnOptions(interp, objc, objv,
 	    &mergedOpts, &code, &level)) {
